s3 method to add netify_edge objects to ggplot objects. this method is called automatically when using the + operator with a netify_edge object.
Arguments
- object
a netify_edge object created by
netify_edge- plot
a ggplot object to which the edge layer will be added
- ...
additional arguments passed by ggplot2 (used internally)