Skip to contents

randomly selects and returns one of the available network styles

Usage

style_random(seed = NULL)

Arguments

seed

optional seed for reproducibility

Value

a style list that can be passed to plot()

Author

cassy dorff, shahryar minhas