this is the internal workhorse function called by the s3 method subset.netify.
users should typically use subset() on netify objects rather than calling
this function directly.
Arguments
- netlet
a netify object to subset
- actors
character vector of actor names or numeric indices to subset
- time
time periods to subset
- layers
character vector of layer names to subset from multilayer networks
- from
character vector of actor names or numeric indices for actors sending ties
- to
character vector of actor names or numeric indices for actors receiving ties