Skip to contents

S3 method to add netify_edge objects to ggplot objects. This method is called automatically when using the + operator with a netify_edge object.

Usage

# S3 method for class 'netify_edge'
ggplot_add(object, plot, ...)

Arguments

object

A netify_edge object created by netify_edge

plot

A ggplot object to which the edge layer will be added

...

Additional arguments passed by ggplot2 (used internally)

Value

A ggplot object with the edge layer added