S3 method to add netify_edge objects to ggplot objects. This method is called automatically when using the + operator with a netify_edge object.
Arguments
- object
A netify_edge object created by
netify_edge- plot
A ggplot object to which the edge layer will be added
- ...
Additional arguments passed by ggplot2 (used internally)