s3 method to add netify_label objects to ggplot objects. this method is called automatically when using the + operator with a netify_label object.
Usage
# S3 method for class 'netify_label'
ggplot_add(object, plot, ...)Arguments
- object
a netify_label object created by
netify_label- plot
a ggplot object to which the label layer will be added
- ...
additional arguments passed by ggplot2 (used internally)