S3 method to add netify_label objects to ggplot objects. This method is called automatically when using the + operator with a netify_label object.
Arguments
- object
A netify_label object created by
netify_label- plot
A ggplot object to which the label layer will be added
- ...
Additional arguments passed by ggplot2 (used internally)