S3 method to add netify_labels objects to ggplot objects. This method updates the labels of existing scales based on the specifications in the netify_labels object.
Arguments
- object
A netify_labels object created by
netify_scale_labels- plot
A ggplot object to which the labels will be added
- ...
Additional arguments passed by ggplot2 (used internally)