Skip to contents

S3 method to add netify_node objects to ggplot objects. This method is called automatically when using the + operator with a netify_node object.

Usage

# S3 method for class 'netify_node'
ggplot_add(object, plot, ...)

Arguments

object

A netify_node object created by netify_node

plot

A ggplot object to which the node layer will be added

...

Additional arguments passed by ggplot2 (used internally)

Value

A ggplot object with the node layer added