s3 method to add scale reset objects to ggplot objects. this method resets color, fill, alpha, and size scales using the ggnewscale package.
Usage
# S3 method for class 'netify_scale_reset'
ggplot_add(object, plot, ...)Arguments
- object
a netify_scale_reset object created by
reset_scales- plot
a ggplot object to which scale resets will be added
- ...
additional arguments passed by ggplot2 (used internally)