S3 method to add scale reset objects to ggplot objects. This method resets color, fill, alpha, and size scales using the ggnewscale package.
Arguments
- object
A netify_scale_reset object created by
reset_scales- plot
A ggplot object to which scale resets will be added
- ...
Additional arguments passed by ggplot2 (used internally)