S3 method to add netify_text objects to ggplot objects. This method is called automatically when using the + operator with a netify_text object.
Arguments
- object
A netify_text object created by
netify_text- plot
A ggplot object to which the text layer will be added
- ...
Additional arguments passed by ggplot2 (used internally)