R/plot_styles.R
style_random.Rd
randomly selects and returns one of the available network styles
style_random(seed = NULL)
optional seed for reproducibility
a style list that can be passed to plot()
cassy dorff, shahryar minhas