this function returns a customized theme for netify plots.
it is based on the theme_minimal function from the ggplot2 package.
it removes axis text and titles from the plot.
this function returns a customized theme for netify plots.
it is based on the theme_minimal function from the ggplot2 package.
it removes axis text and titles from the plot.